/**
 * Copyright (c) 2009 - 2019, Nordic Semiconductor ASA
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form, except as embedded into a Nordic
 *    Semiconductor ASA integrated circuit in a product or a software update for
 *    such product, must reproduce the above copyright notice, this list of
 *    conditions and the following disclaimer in the documentation and/or other
 *    materials provided with the distribution.
 *
 * 3. Neither the name of Nordic Semiconductor ASA nor the names of its
 *    contributors may be used to endorse or promote products derived from this
 *    software without specific prior written permission.
 *
 * 4. This software, with or without modification, must only be used with a
 *    Nordic Semiconductor ASA integrated circuit.
 *
 * 5. Any software provided in binary form under this license must not be reverse
 *    engineered, decompiled, modified and/or disassembled.
 *
 * THIS SOFTWARE IS PROVIDED BY NORDIC SEMICONDUCTOR ASA "AS IS" AND ANY EXPRESS
 * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, NONINFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL NORDIC SEMICONDUCTOR ASA OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */
/** @file
* @brief Example template project.
* @defgroup nrf_templates_example Example Template
*
*/

#include <stdbool.h>
#include <stdint.h>
#include <stdio.h>

#include "nrf_drv_twi.h"
#include "nrf_log.h"
#include "nrf_log_ctrl.h"
#include "nrf_log_default_backends.h"

#include "nrf.h"
#include "nrf_delay.h"
#include "nrf_gpio.h"

#include "app_error.h"
#include "app_mpu.h"
#include "app_uart.h"
#include "boards.h"
#include "nordic_common.h"
#include "nrf.h"
#include "nrf_uart.h"

#include "drivers_ext/mpu6050/mpu6050.h"

#define MAX_TEST_DATA_BYTES (15U) /**< max number of test bytes to be used for tx and rx. */
#define UART_TX_BUF_SIZE 256      /**< UART TX buffer size. */
#define UART_RX_BUF_SIZE 256      /**< UART RX buffer size. */

void uart_error_handle(app_uart_evt_t *p_event)
{
    if (p_event->evt_type == APP_UART_COMMUNICATION_ERROR)
    {
	APP_ERROR_HANDLER(p_event->data.error_communication);
    }
    else if (p_event->evt_type == APP_UART_FIFO_ERROR)
    {
	APP_ERROR_HANDLER(p_event->data.error_code);
    }
}
#define UART_HWFC APP_UART_FLOW_CONTROL_DISABLED

static void log_init(void)
{
    ret_code_t err_code = NRF_LOG_INIT(NULL);
    APP_ERROR_CHECK(err_code);

    NRF_LOG_DEFAULT_BACKENDS_INIT();
}

void mpu_init(void)
{
    ret_code_t ret_code;
    // Initiate MPU driver
    ret_code = app_mpu_init();
    APP_ERROR_CHECK(ret_code); // Check for errors in return value

    // Setup and configure the MPU with intial values
    app_mpu_config_t p_mpu_config     = MPU_DEFAULT_CONFIG();          // Load default values
    p_mpu_config.smplrt_div           = 19;                            // Change sampelrate. Sample Rate = Gyroscope Output Rate / (1 + SMPLRT_DIV). 19 gives a sample rate of 50Hz
    p_mpu_config.accel_config.afs_sel = AFS_2G;                        // Set accelerometer full scale range to 2G
    ret_code                          = app_mpu_config(&p_mpu_config); // Configure the MPU with above values
    APP_ERROR_CHECK(ret_code);                                         // Check for errors in return value
}

/**
 * @brief Function for main application entry.
 */
int main(void)
{
    uint32_t err_code;

    // Initialize.
    log_init();
    //NRF_LOG_INFO("\033[2J\033[;H"); // Clear screen

    mpu_init();
    nrf_gpio_cfg_output(NRF_GPIO_PIN_MAP(1, 01));
    // Start execution.
    //NRF_LOG_INFO("MPU Free Fall Interrupt example.");
    //printf("MPU example");
    accel_values_t acc_values;
    uint32_t       sample_number = 0;

    while (1)
    {
	//printf("Hello");
//	if (NRF_LOG_PROCESS() == false)
//	{
//	    
//	}
        // Read accelerometer sensor values
	    err_code = app_mpu_read_accel(&acc_values);
            
	    APP_ERROR_CHECK(err_code);
	    // Clear terminal and print values
//	    NRF_LOG_INFO("\033[3;1HSample # %d\r\nX: %06d\r\nY: %06d\r\nZ: %06d", 
//	    ++sample_number, acc_values.x, acc_values.y, acc_values.z);
	    if (acc_values.x > 0.1f)
	    {
		nrf_gpio_pin_set(NRF_GPIO_PIN_MAP(1, 01));
	    }
	    else
	    {
		nrf_gpio_pin_clear(NRF_GPIO_PIN_MAP(1, 01));
	    }
//            printf("X: %06d\r\nY: %06d\r\nZ: %06d",
//	    acc_values.x, acc_values.y, acc_values.z);

	    nrf_delay_ms(200);
    }
}
/** @} */